summaryrefslogtreecommitdiffstats
path: root/kcontrol/background/bghash.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcontrol/background/bghash.h')
-rw-r--r--kcontrol/background/bghash.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kcontrol/background/bghash.h b/kcontrol/background/bghash.h
index 932c6ebab..ab13daf90 100644
--- a/kcontrol/background/bghash.h
+++ b/kcontrol/background/bghash.h
@@ -2,13 +2,13 @@
#define BGHASH_H
/*
* QString -> int hash. From Qt's QGDict::hashKeyString().
*/
-static int QHash(QString key)
+static int QHash(TQString key)
{
int g, h = 0;
- const QChar *p = key.unicode();
+ const TQChar *p = key.unicode();
for (unsigned i=0; i < key.length(); i++) {
h = (h << 4) + p[i].cell();
if ((g = (h & 0xf0000000)))
@@ -2,13 +2,13 @@
#define BGHASH_H
/*
- * QString -> int hash. From Qt's QGDict::hashKeyString().
+ * TQString -> int hash. From Qt's TQGDict::hashKeyString().
*/